@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Extension to File::Basename, adds named access to file parts and handling of filename suffixes
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 #pod =head1 SYNOPSIS
 #pod
@@ -293,7 +293,7 @@ File::Basename::Extra - Extension to File::Basename, adds named access to file p
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -455,8 +455,8 @@ optionally changing it.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website
-https://github.com/HayoBaan/File-Basename-Extra/issues
+Please report any bugs or feature requests on the bugtracker
+L<website|https://github.com/HayoBaan/File-Basename-Extra/issues>.
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -468,7 +468,7 @@ L<File::Basename> for the suffix matching and platform specific details.
 
 =head1 AUTHOR
 
-Hayo Baan <info@hayobaan.com>
+Hayo Baan <hayobaan@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
